

class MMS_TestClass:
	def __init__(self, a, b):
		self.a = a
		self.b = b

	def add(self):
		return self.a + self.b

	def abs_diff(self, val1, val2):
		return abs(val1-val2)

	def output(self):
		return 'Kack Fabi! Beeil dich! Wir ham Hunger!'
